==> nextcloud-26.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/he.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "מעגלים",
    "Circles' files" : "קבצים של מעגלים",
    "Select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No circles found" : "לא נמצאו מעגלים",
    "Please select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No files found for the selected circles" : "לא נמצאו קבצים למעגלים הנבחרים",
    "You created the circle {circle}" : "יצרת את המעגל {circle}",
    "{author} created the circle {circle}" : "המעגל {circle} נוצר על ידי {author}",
    "You deleted {circle}" : "מחקת את {circle}",
    "{author} deleted {circle}" : "{circle} נמחק על ידי {author}",
    "You linked {group} to {circle}" : "קישרת את {group} אל {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} קושרה אל {circle} על ידי {author}",
    "You unlinked {group} from {circle}" : "ניתקת את {group} מהמעגל {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} נותקה מהמעגל {circle} על ידי {author}",
    "You sent a request to link {circle} with {remote}" : "שלחת בקשה לקשר את {circle} אל {remote}",
    "{author} sent a request to link {circle} with {remote}" : "נשלחה בקשה על ידי {author} לקשר את {circle} אל {remote}",
    "{remote} requested a link with {circle}" : "התקבלה בקשה לקישור מול {circle} על ידי {remote}",
    "The request to link {circle} with {remote} has been rejected" : "הבקשה לקשר את {circle} אל {remote} נדחתה",
    "The request to link {remote} with {circle} has been canceled remotely" : "הבקשה לקשר את {circle} אל {remote} בוטלה מהצד השני",
    "The request to link {circle} with {remote} has been accepted" : "הבקשה לקשר את {circle} אל {remote} התקבלה",
    "You canceled the request to link {circle} with {remote}" : "ביטלת את הבקשה לקשר את {circle} אל {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "הבקשה לקשר את {circle} אל {remote} בוטלה על ידי {author}",
    "You accepted the request to link {remote} with {circle}" : "נענית לבקשה לקשר את {remote} אל {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "הבקשה לקשר את {circle} אל {remote} נענתה על ידי {author}",
    "A link between {circle} and {remote} is now up and running" : "קישור בין {circle} לבין {remote} פעיל כעת",
    "The link between {circle} and {remote} has been shutdown remotely" : "הקישור בין {circle} לבין {remote} נכבה מרחוק",
    "You closed the link between {circle} and {remote}" : "סגרת את הקישור בין {circle} לבין {remote}",
    "{author} closed the link between {circle} and {remote}" : "הקישור בין {circle} לבין {remote} נסגר על ידי {author}",
    "You joined {circle}" : "הטרפת אל {circle}",
    "You accepted the invitation to join {circle}" : "קיבלת את הבקשה להצטרף אל {circle}",
    "{member} accepted the invitation to join {circle}" : "הבקשה להצטרף אל {circle} התקבלה על ידי {member}",
    "You added {member} as member to {circle}" : "הוספת את {member} לחברות במעגל {circle}",
    "You added {external} to {circle}" : "הוספת את {external} אל {circle}",
    "You accepted {member}'s request to join {circle}" : "נענית לבקשה של {member} להצטרף אל {circle}",
    "Your request to join {circle} has been accepted by {author}" : "בקשתך להצטרף אל {circle} נענתה על ידי {author}",
    "You left {circle}" : "עזבת את {circle}",
    "You declined the invitation to join {circle}" : "דחית את ההזמנה להצטרף אל {circle}",
    "You cancelled your request to join {circle}" : "ביטלת את בקשתך להצטרף אל {circle}",
    "You removed {member} from {circle}" : "הסרת את {member} מהמעגל {circle}",
    "You have been removed from {circle} by {author}" : "הוסרת מהמעגל {circle} על ידי {author}",
    "You removed {external} from {circle}" : "הסרת את {external} מהמעגל {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "ביטלת את ההזמנה של {member} להצטרף אל {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "הזמנתך להצטרף אל {circle} בוטלה על ידי {author}",
    "You invited {member} to join {circle}" : "הזמנת את {member} להצטרף אל {circle}",
    "You have been invited to join {circle} by {author}" : "הוזמנת להצטרף אל {circle} על ידי {author}",
    "You sent a request to join {circle}" : "שלחת בקשה להצטרף אל {circle}",
    "{member} sent a request to join {circle}" : "נשלחה בקשה על ידי {member} להצטרף אל {circle}",
    "You are the new owner of {circle}" : "קיבלת בעלות על {circle}",
    "{member} is the new owner of {circle}" : "הבעלות על {circle} הועברה לידי {member}",
    "Single" : "בודד",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Visible" : "גלוי",
    "Open" : "פתוח",
    "Invite" : "הזמנה",
    "Join Request" : "בקשת הצטרפות",
    "Friends" : "חברים",
    "Password Protected" : "מוגן בססמה",
    "No Owner" : "אין בעלים",
    "Hidden" : "מוסתר",
    "Backend" : "מנגנון",
    "Local" : "מקומי",
    "Root" : "בסיס",
    "Circle Invite" : "הזמנה למעגל",
    "Federated" : "Federated",
    "Mount point" : "נקודת עיגון",
    "Nextcloud Group" : "קבוצת Nextcloud",
    "Email Address" : "כתובת דוא״ל",
    "Contact" : "איש/אשת קשר",
    "Circle" : "מעגל",
    "Nextcloud App" : "יישומון Nextcloud",
    "Member" : "חבר",
    "Moderator" : "פיקוח",
    "Admin" : "מנהל",
    "Owner" : "בעלות",
    "Password to access »%1$s« shared to you by %2$s" : "סיסמא לגישה ל-»%1$s« משותף לך על ידי %2$s",
    "Password to access »%s«" : "ססמת הגישה אל „%s”",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
    "Open »%s«" : "פתיחת „%s”",
    "Password to access files" : "ססמה לגשת לקבצים",
    "Fresh installation status" : "מצב ההתקנה החדשה",
    "Building Local Database" : "מסד הנתונים המקומי נבנה",
    "Testing Basic Circle Creation" : "נבדקת יצירת מעגל בסיסי",
    "Adding local users and moderators" : "הוספת משתמשים ומפקחים מקומיים",
    "Circle not found" : "המעגל לא נמצא",
    "Circle not found " : "המעגל לא נמצא",
    "This member does not exist" : "חבר זה אינו קיים",
    "This feature is not available for personal circles" : "תכונה זו אינה זמינה למעגלים אישיים",
    "You cannot join this circle" : "אין לך אפשרות להצטרף למעגל הזה",
    "Insufficient privileges" : "אין מספיק הרשאות",
    "This member is the owner of the circle" : "חבר זה הוא בעל המעגל",
    "You are already a member of this circle" : "כבר יש לך חברות במעגל זה",
    "You have been blocked from this circle" : "גישתך למעגל הזה נחסמה",
    "You are now a member of the Circle \"%2$s\"" : "התקבלת לחברות במעגל „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "הוזמנת על ידי %1$s למעגל „%2$s”",
    "Accept" : "אשר",
    "Refuse" : "סירוב",
    "Leave the circle" : "לעזוב את המעגל",
    "%s" : "%s",
    "Personal Circle" : "מעגל אישי",
    "You need a specify a type of circle" : "עליך לציין את סוג המעגל",
    "A circle with that name exists" : "כבר קיים מעגל בשם הזה",
    "This member is not the owner of the circle" : "חבר זה אינו הבעלים של המעגל",
    "This member is not an admin of the circle" : "חבר זה אינו מנהל של המעגל",
    "Group contains too many members" : "הקבוצה מכילה יותר מדי חברים",
    "This group does not exist" : "קבוצה זו אינה קיימת",
    "This group is already linked to the circle" : "קבוצה זו כבר מקושרת למעגל זה",
    "now" : "עכשיו",
    "Email format is not valid" : "תצורת הדוא״ל שגויה",
    "This contact is not available" : "איש קשר זה אינו זמין",
    "This item is already shared with this circle" : "פריט זה כבר שותף עם המעגל הזה",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי",
    "Nextcloud User" : "משתמש Nextcloud",
    "Initialisation Circles App" : "יישומון המעגלים נטען",
    "This user is already a member of the circle" : "משתמש זה כבר חבר במעגל",
    "The user is already a member of this circle" : "המשתמש הוא כבר חבר במעגל הזה",
    "The user has already been invited into this circle" : "המשתמש הזה כבר הוזמן למעגל הזה",
    "This user does not exist" : "המשתמש הזה לא קיים",
    "Could not find share" : "לא ניתן למצוא את השיתוף"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/he.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "מחקת את {circle}",
    "{author} deleted {circle}" : "{circle} נמחק על ידי {author}",
    "You joined {circle}" : "הטרפת אל {circle}",
    "You accepted the invitation to join {circle}" : "קיבלת את הבקשה להצטרף אל {circle}",
    "{member} accepted the invitation to join {circle}" : "הבקשה להצטרף אל {circle} התקבלה על ידי {member}",
    "You added {member} as member to {circle}" : "הוספת את {member} לחברות במעגל {circle}",
    "You added {external} to {circle}" : "הוספת את {external} אל {circle}",
    "You accepted {member}'s request to join {circle}" : "נענית לבקשה של {member} להצטרף אל {circle}",
    "Your request to join {circle} has been accepted by {author}" : "בקשתך להצטרף אל {circle} נענתה על ידי {author}",
    "You left {circle}" : "עזבת את {circle}",
    "You declined the invitation to join {circle}" : "דחית את ההזמנה להצטרף אל {circle}",
    "You cancelled your request to join {circle}" : "ביטלת את בקשתך להצטרף אל {circle}",
    "You removed {member} from {circle}" : "הסרת את {member} מהמעגל {circle}",
    "You have been removed from {circle} by {author}" : "הוסרת מהמעגל {circle} על ידי {author}",
    "You removed {external} from {circle}" : "הסרת את {external} מהמעגל {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "ביטלת את ההזמנה של {member} להצטרף אל {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "הזמנתך להצטרף אל {circle} בוטלה על ידי {author}",
    "You invited {member} to join {circle}" : "הזמנת את {member} להצטרף אל {circle}",
    "You have been invited to join {circle} by {author}" : "הוזמנת להצטרף אל {circle} על ידי {author}",
    "You sent a request to join {circle}" : "שלחת בקשה להצטרף אל {circle}",
    "{member} sent a request to join {circle}" : "נשלחה בקשה על ידי {member} להצטרף אל {circle}",
    "You are the new owner of {circle}" : "קיבלת בעלות על {circle}",
    "{member} is the new owner of {circle}" : "הבעלות על {circle} הועברה לידי {member}",
    "Shared to Circles" : "שותף למעגלים",
    "Single" : "בודד",
    "Personal" : "אישי",
    "System" : "מערכת",
    "Visible" : "גלוי",
    "Open" : "פתוח",
    "Invite" : "הזמנה",
    "Friends" : "חברים",
    "Password protected" : "מוגן בססמה",
    "No Owner" : "אין בעלים",
    "Hidden" : "מוסתר",
    "Backend" : "מנגנון",
    "Local" : "מקומי",
    "Root" : "בסיס",
    "Federated" : "Federated",
    "Mount point" : "נקודת עיגון",
    "Nextcloud Group" : "קבוצת Nextcloud",
    "Email address" : "כתובת דוא״ל",
    "Contact" : "איש/אשת קשר",
    "Circle" : "מעגל",
    "Nextcloud App" : "יישומון Nextcloud",
    "Member" : "חבר",
    "Moderator" : "פיקוח",
    "Admin" : "מנהל",
    "Owner" : "בעלות",
    "Password to access »%1$s« shared to you by %2$s" : "סיסמא לגישה ל-»%1$s« משותף לך על ידי %2$s",
    "Password to access »%s«" : "ססמת הגישה אל „%s”",
    "It is protected with the following password:" : "הוא מוגן בססמה הבאה:",
    "%1$s via %2$s" : "%1$s דרך %2$s",
    "Click the button below to open it." : "יש ללחוץ על הכפתור להלן כדי לפתוח אותו.",
    "Open »%s«" : "פתיחת „%s”",
    "Password to access files" : "ססמה לגשת לקבצים",
    "Fresh installation status" : "מצב ההתקנה החדשה",
    "Building Local Database" : "מסד הנתונים המקומי נבנה",
    "Testing Basic Circle Creation" : "נבדקת יצירת מעגל בסיסי",
    "Adding local users and moderators" : "הוספת משתמשים ומפקחים מקומיים",
    "Files" : "קבצים",
    "This feature is not available for personal circles" : "תכונה זו אינה זמינה למעגלים אישיים",
    "Insufficient privileges" : "אין מספיק הרשאות",
    "This member does not exist" : "חבר זה אינו קיים",
    "You are already a member of this circle" : "כבר יש לך חברות במעגל זה",
    "You have been blocked from this circle" : "גישתך למעגל הזה נחסמה",
    "You are now a member of the Circle \"%2$s\"" : "התקבלת לחברות במעגל „%2$s”",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "הוזמנת על ידי %1$s למעגל „%2$s”",
    "Accept" : "אשר",
    "Refuse" : "סירוב",
    "Leave the circle" : "לעזוב את המעגל",
    "%s" : "%s",
    "No files in here" : "אין כאן קבצים",
    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "מועד שינוי",
    "Circles" : "מעגלים",
    "Circles' files" : "קבצים של מעגלים",
    "Select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No circles found" : "לא נמצאו מעגלים",
    "Please select circles to filter by" : "נא לבחור מעגלים לסינון",
    "No files found for the selected circles" : "לא נמצאו קבצים למעגלים הנבחרים",
    "You created the circle {circle}" : "יצרת את המעגל {circle}",
    "{author} created the circle {circle}" : "המעגל {circle} נוצר על ידי {author}",
    "Join Request" : "בקשת הצטרפות",
    "Password Protected" : "מוגן בססמה",
    "Circle Invite" : "הזמנה למעגל",
    "Email Address" : "כתובת דוא״ל",
    "Initialisation Circles App" : "יישומון המעגלים נטען",
    "Circle not found" : "המעגל לא נמצא",
    "Circle not found " : "המעגל לא נמצא",
    "You cannot join this circle" : "אין לך אפשרות להצטרף למעגל הזה",
    "This member is the owner of the circle" : "חבר זה הוא בעל המעגל",
    "Personal Circle" : "מעגל אישי",
    "You need a specify a type of circle" : "עליך לציין את סוג המעגל",
    "A circle with that name exists" : "כבר קיים מעגל בשם הזה",
    "This member is not the owner of the circle" : "חבר זה אינו הבעלים של המעגל",
    "This member is not an admin of the circle" : "חבר זה אינו מנהל של המעגל",
    "Group contains too many members" : "הקבוצה מכילה יותר מדי חברים",
    "This group does not exist" : "קבוצה זו אינה קיימת",
    "This group is already linked to the circle" : "קבוצה זו כבר מקושרת למעגל זה",
    "now" : "עכשיו",
    "Email format is not valid" : "תצורת הדוא״ל שגויה",
    "This contact is not available" : "איש קשר זה אינו זמין",
    "This item is already shared with this circle" : "פריט זה כבר שותף עם המעגל הזה"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
